@@ -11,19 +11,20 @@ The code is licensed under the MIT license.
 import warnings
 
 
-def _warning_on_one_line(message, category, filename, lineno, line=None) -> str:  # pylint: disable=unused-argument
+def _warning_on_one_line(message, category, *args ,**kwargs) -> str:  # pylint: disable=unused-argument
     """
     Print warning on a single line
     """
     return '%s: %s\n' % (category.__name__, message)
 
-
 # Set warning format
 warnings.formatwarning = _warning_on_one_line
 
-
 def warn(message: str) -> None:
     """
     Create a warning
     """
-    warnings.warn(message, Warning)
+    try:
+        warnings.warn(message, Warning)
+    except TypeError:
+        pass
